%  k-means method for trends (KMT) sample program
%
%  by Norio Watanabe, Chuo University, JAPAN
%                                        11/12/2022
%                                        10/20/2022
%                                        08/06/2021
%
%  Reference:
%     A k-means method for trends of time series: An application to 
%     time series of COVID-19 cases in Japan
%          Japanese Journal of Statistics and Data Science, 2022
%
%  contents:
%     KMT1.m : main M-file using following functions
%           kmeansTrendL.m
%           CommonTrendL.m
%           fun_dsmCT.m
%           fun_dsmT.m
%     KMT2.m : auxiliary program (sort and summarize)
%
clear
close all
K=3;      % number of clusters ( several values of K should be tried )
Lmax=30;   % max lag (depends on time series. 0 is also accepted)
JCmax=20; % iteration number
           % set large, if not well classified becuase of sensitivity on initial values
rand('seed',87) % for setting initial values (old style)
           
%%%%%%%%%%%%%%%%%%
%
% X: N x P matrix
%    P-variate trend [for example, moving averaged time sieries ]
%    N:length of series
%
fname='data';
load(strcat(fname,'.mat'));%%% loading data matrix X
% load('data.mat'); 
%
% data.mat : moving averaged Covid-19 cases in Japan
%            original data are provided by NHK (Japan Broadcasting Corporation) 
%
% or, for example
% X=load(strcat(fname,'.txt')):
%
%%%%%%%%%%%%%%%%%%
[N,P]=size(X);
[CMT,kc,Lag,R,Jmin]=kmeansTrendL(X,K,JCmax,Lmax);
%%%%%%%%%%%%%%%%%%

NT=N-2*Lmax;
for k=1:K
    subplot(K,1,k)
    hold on
    for p=1:P
        n1=Lmax+1+Lag(p);
        n2=N-Lmax+Lag(p);
        if kc(p)==k
%             x=CMT(:,k);
            y=X(:,p);
            plot([N-n2+1:N-n1+1],R(p)*y(n1:n2),'b:')
        end
    end
    plot([Lmax+1:N-Lmax],CMT(:,k),'r-','LineWidth',3)
    hold off
    box on
end
for k=1:K
    sum(kc==k)
end

Jmin

% save results ( used by KMT2.m )
save(strcat(fname,'_res'),'K','Lmax','Jmin','kc','Lag','R','CMT') 


